==> facebook-java-business-sdk-6.0.3-sources.jar: com/facebook/ads/utils/ServerSideApiConstants.java <==
/**
 * Copyright (c) 2015-present, Facebook, Inc. All rights reserved.
 * <p>
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to use, copy, modify, and
 * distribute this software in source code or binary form for use in connection with the web
 * services and APIs provided by Facebook.
 * <p>
 * As with any software that integrates with the Facebook platform, your use of this software is
 * subject to the Facebook Developer Principles and Policies [http://developers.facebook.com/policy/].
 * This copyright notice shall be included in all copies or substantial portions of the software.
 * <p>
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package com.facebook.ads.utils;

public class ServerSideApiConstants {

    public static final String EMAIL = "em";

    public static final String PHONE_NUMBER = "ph";

    public static final String GENDER = "ge";

    public static final String DATE_OF_BIRTH = "db";

    public static final String LAST_NAME = "ln";

    public static final String FIRST_NAME = "fn";

    public static final String CITY = "ct";

    public static final String COUNTRY = "country";

    public static final String STATE = "st";

    public static final String ZIP_CODE = "zp";

    public static final String EXTERNAL_ID = "external_id";

    public static final String CURRENCY = "currency";
}

==> facebook-java-business-sdk-9.0.1-sources.jar: com/facebook/ads/utils/ServerSideApiConstants.java <==
/**
 * Copyright (c) 2015-present, Facebook, Inc. All rights reserved.
 * <p>
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to use, copy, modify, and
 * distribute this software in source code or binary form for use in connection with the web
 * services and APIs provided by Facebook.
 * <p>
 * As with any software that integrates with the Facebook platform, your use of this software is
 * subject to the Facebook Developer Principles and Policies [http://developers.facebook.com/policy/].
 * This copyright notice shall be included in all copies or substantial portions of the software.
 * <p>
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package com.facebook.ads.utils;

public class ServerSideApiConstants {

    public static final String EMAIL = "em";

    public static final String PHONE_NUMBER = "ph";

    public static final String GENDER = "ge";

    public static final String DATE_OF_BIRTH = "db";

    public static final String LAST_NAME = "ln";

    public static final String FIRST_NAME = "fn";

    public static final String CITY = "ct";

    public static final String COUNTRY = "country";

    public static final String STATE = "st";

    public static final String ZIP_CODE = "zp";

    public static final String EXTERNAL_ID = "external_id";

    public static final String CURRENCY = "currency";

    public static final String CLIENT_IP_ADDRESS = "client_ip_address";

    public static final String CLIENT_USER_AGENT = "client_user_agent";

    public static final String FBC = "fbc";

    public static final String FBP = "fbp";

    public static final String SUBSCRIPTION_ID = "subscription_id";

    public static final String FB_LOGIN_ID = "fb_login_id";

    public static final String LEAD_ID = "lead_id";

    public static final String F5FIRST = "f5first";

    public static final String F5LAST = "f5last";

    public static final String FI = "fi";

    public static final String DOBD = "dobd";

    public static final String DOBM = "dobm";

    public static final String DOBY = "doby";
}
